==> peg-e_1.1.2.orig.tar.bz2: peg-e-1.1.2/translations/pege_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="193"/>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="193"/>
        <source>Game Over</source>
        <translation>המשחק נגמר</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>בחירת שפת יישום:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="181"/>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="181"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <location filename="../src/window.cpp" line="246"/>
        <source>Peg-E</source>
        <translation>‫Peg-E</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="58"/>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="62"/>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="62"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="66"/>
        <source>&amp;Restart Game</source>
        <translation>&amp;התחל מחדש</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="66"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="68"/>
        <source>&amp;Details</source>
        <translation>&amp;פרטים</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>Quit</source>
        <translation>יציאה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>&amp;Move</source>
        <translation>&amp;תור</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>&amp;Undo</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>Ctrl+z</source>
        <translation>Ctrl+z</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="86"/>
        <source>&amp;Redo</source>
        <translation>&amp;חזרה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="86"/>
        <source>Shift+Ctrl+Z</source>
        <translation>Shift+Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="90"/>
        <source>&amp;Appearance</source>
        <translation>&amp;מראה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>Blue</source>
        <translation>כחול</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="94"/>
        <source>Charcoal</source>
        <translation>פחם</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <source>Green</source>
        <translation>ירוק</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="96"/>
        <source>Midnight</source>
        <translation>חצות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="97"/>
        <source>Plum</source>
        <translation>שזיף</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="98"/>
        <source>Red</source>
        <translation>אדום</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="99"/>
        <source>Yellow</source>
        <translation>צהוב</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="117"/>
        <source>Custom...</source>
        <translation>אחר...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="119"/>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="124"/>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;QT</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="161"/>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <location filename="../src/window.cpp" line="225"/>
        <location filename="../src/window.cpp" line="317"/>
        <source>Original</source>
        <translation>מקורי</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="166"/>
        <location filename="../src/window.cpp" line="218"/>
        <location filename="../src/window.cpp" line="320"/>
        <source>Branch</source>
        <translation>מסועף</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="167"/>
        <location filename="../src/window.cpp" line="221"/>
        <location filename="../src/window.cpp" line="323"/>
        <source>Line</source>
        <translation>שורה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>Random</source>
        <translation>אקראי</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="186"/>
        <source>Algorithm:</source>
        <translation>אלגוריתם:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="187"/>
        <source>Difficulty:</source>
        <translation>קושי:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="188"/>
        <source>Seed:</source>
        <translation>זרעים:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="205"/>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="205"/>
        <source>Do you want to restart?</source>
        <translation>האם ברצונך להתחיל מחדש?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>Details</source>
        <translation>פרטים</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;אלגוריתם:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;קושי:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;זרעים:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="243"/>
        <source>About Peg-E</source>
        <translation>אודות ‫Peg-E</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="247"/>
        <source>Peg elimination game</source>
        <translation>משחק הלוח מחשבת</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="248"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="249"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="250"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>הצלמיות נלקחו מן הפרויקט &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="251"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>בשימוש תחת הרשיון &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> peg-e-1.3.5.tar.bz2: peg-e-1.3.5/translations/pege_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>המשחק נגמר</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחר שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>אנא אתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Peg-E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Restart Game</source>
        <translation>&amp;התחל מחדש</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;פרטים</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>יציאה</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;צעד</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;בטל</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>בצ&amp;ע שוב</translation>
    </message>
    <message>
        <source>&amp;Appearance</source>
        <translation>&amp;מראה</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>כחול</translation>
    </message>
    <message>
        <source>Charcoal</source>
        <translation>פחם</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>ירוק</translation>
    </message>
    <message>
        <source>Midnight</source>
        <translation>חצות</translation>
    </message>
    <message>
        <source>Plum</source>
        <translation>שזיף</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>אדום</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>צהוב</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>מותאם...</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>מקורי</translation>
    </message>
    <message>
        <source>Branch</source>
        <translation>מסועף</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>שורה</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>אקראי</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>אלגוריתם:</translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>קושי:</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>זרעים:</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Do you want to restart?</source>
        <translation>האם ברצונך להתחיל מחדש?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>פרטים</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;אלגוריתם:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;קושי:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;זרעים:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Peg-E</source>
        <translation>אודות ‫Peg-E</translation>
    </message>
    <message>
        <source>Peg elimination game</source>
        <translation>משחק לוח מחשבת</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>סמלים נלקחו מתוך פרויקט &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>בשימוש תחת הרשיון &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
